@@ -8,15 +8,16 @@ from setux.repl.repl import repl, prompt
 from .usage import usage
 
 
-def get_target(name=None):
+def get_target(name=None, dest=None):
     name = name or environ.get('setux_target')
+    dest = dest or environ.get('setux_outdir', '/var/log/setux')
     if name:
         try:
-            target = SSH(name=name, host=name)
+            target = SSH(name=name, host=name, outdir=dest)
         except:
             target = None
     else:
-        target = Local()
+        target = Local(outdir=dest)
     return target
 
 
